@@ -1,4 +1,4 @@
-import Gdk from 'gi://Gdk?version=4.0';
+import Adw from 'gi://Adw';
 import Gio from 'gi://Gio';
 import GLib from 'gi://GLib';
 import GObject from 'gi://GObject';
@@ -9,7 +9,6 @@ import Tp from 'gi://TelepathyGLib';
 import { setConsoleLogDomain } from 'console';
 
 import AccountsMonitor from './accountsMonitor.js';
-import * as AppNotifications from './appNotifications.js';
 import * as Connections from './connections.js';
 import InitialSetupWindow from './initialSetup.js';
 import MainWindow from './mainWindow.js';
@@ -37,14 +36,15 @@ const MAX_RETRIES = 3;
 
 const IRC_SCHEMA_REGEX = /^(irc?:\/\/)([\da-z.-]+):?(\d+)?\/(?:%23)?([\w.+-]+)/i;
 
-export default GObject.registerClass({
-    Signals: {
+export default GObject.registerClass(
+class Application extends Adw.Application {
+    static [GObject.signals] = {
         'prepare-shutdown': {},
         'room-focus-changed': {},
-    },
-}, class Application extends Gtk.Application {
-    _init() {
-        super._init({
+    };
+
+    constructor() {
+        super({
             application_id: 'org.gnome.Polari',
             flags: Gio.ApplicationFlags.HANDLES_OPEN,
         });
@@ -57,6 +57,8 @@ export default GObject.registerClass({
         if (GLib.log_writer_is_journald(2))
             GLib.setenv('G_MESSAGES_DEBUG', logDomain, false);
 
+        this._removedAccounts = new Set();
+
         this._retryData = new Map();
         this._nickTrackData = new Map();
         this._demons = [];
@@ -269,6 +271,10 @@ export default GObject.registerClass({
             name: 'remove-connection',
             activate: this._onRemoveConnection.bind(this),
             parameter_type: GLib.VariantType.new('o'),
+        }, {
+            name: 'undo-remove-connection',
+            activate: this._onUndoRemoveConnection.bind(this),
+            parameter_type: GLib.VariantType.new('o'),
         }, {
             name: 'edit-connection',
             activate: this._onEditConnection.bind(this),
@@ -388,13 +394,6 @@ export default GObject.registerClass({
         });
 
         this.pasteManager = new PasteManager();
-
-        let provider = new Gtk.CssProvider();
-        let uri = 'resource:///org/gnome/Polari/css/application.css';
-        provider.load_from_file(Gio.File.new_for_uri(uri));
-        Gtk.StyleContext.add_provider_for_display(Gdk.Display.get_default(),
-            provider,
-            Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION);
     }
 
     vfunc_activate() {
@@ -498,10 +497,10 @@ export default GObject.registerClass({
             [,, server, port, room] = uri.match(IRC_SCHEMA_REGEX);
             success = true;
         } catch (e) {
-            let label = _('Failed to open link');
-            let n = new AppNotifications.MessageNotification(
-                label, 'dialog-error-symbolic');
-            this.active_window?.queueNotification(n);
+            const toast = new Adw.Toast({
+                title: _('Failed to open link'),
+            });
+            this.active_window?.addToast(toast);
         }
 
         return [success, server, port, room];
@@ -766,22 +765,34 @@ export default GObject.registerClass({
         let account = this._accountsMonitor.lookupAccount(accountPath);
 
         await account.set_enabled_async(false);
+        this._removedAccounts.add(account);
         account.visible = false;
 
-        const label = vprintf(_('%s removed.'), account.display_name);
-        const n = new AppNotifications.UndoNotification(label);
-        this?.active_window.queueNotification(n);
+        const toast = new Adw.Toast({
+            title: vprintf(_('%s removed.'), account.display_name),
+            button_label: _('Undo'),
+            action_name: 'app.undo-remove-connection',
+            action_target: parameter,
+        });
+        toast.connect('dismissed', async () => {
+            if (!this._removedAccounts.delete(account))
+                return;
 
-        n.connect('closed', async () => {
             await account.remove_async(); // TODO: Check for errors
 
             Utils.clearAccountPassword(account);
             Utils.clearIdentifyPassword(account);
         });
-        n.connect('undo', async () => {
-            await account.set_enabled_async(true);
-            account.visible = true;
-        });
+        this?.active_window.addToast(toast);
+    }
+
+    async _onUndoRemoveConnection(action, parameter) {
+        const accountPath = parameter.deep_unpack();
+        const account = this._accountsMonitor.lookupAccount(accountPath);
+
+        this._removedAccounts.delete(account);
+        await account.set_enabled_async(true);
+        account.visible = true;
     }
 
     _onEditConnection(action, parameter) {
