@@ -26,15 +26,16 @@ const ErrorHint = {
 
 const ConnectionRow = GObject.registerClass(
 class ConnectionRow extends Gtk.ListBoxRow {
-    _init(params) {
+    constructor(params) {
         if (!params || !params.id)
             throw new Error('No id in parameters');
 
-        this._id = params.id;
+        const { id } = params;
         delete params.id;
 
-        super._init(params);
+        super(params);
 
+        this._id = id;
         let name = NetworksManager.getDefault().getNetworkName(this._id);
         this.name = `ConnectionRow ${name}`;
 
@@ -72,22 +73,22 @@ class ConnectionRow extends Gtk.ListBoxRow {
     }
 });
 
-export const ConnectionsList = GObject.registerClass({
-    Properties: {
+export const ConnectionsList = GObject.registerClass(
+class ConnectionsList extends Gtk.ScrolledWindow {
+    static [GObject.properties] = {
         'favorites-only': GObject.ParamSpec.boolean(
             'favorites-only', 'favorites-only', 'favorites-only',
             GObject.ParamFlags.READWRITE | GObject.ParamFlags.CONSTRUCT_ONLY,
             false),
-    },
-    Signals: {
+    };
+
+    static [GObject.signals] = {
         'account-created': { param_types: [Tp.Account.$gtype] },
         'account-selected': {},
-    },
-}, class ConnectionsList extends Gtk.ScrolledWindow {
-    _init(params) {
-        this._favoritesOnly = false;
+    };
 
-        super._init(params);
+    constructor(params) {
+        super(params);
 
         this.hscrollbar_policy = Gtk.PolicyType.NEVER;
 
@@ -141,20 +142,6 @@ export const ConnectionsList = GObject.registerClass({
         });
     }
 
-    // eslint-disable-next-line camelcase
-    get favorites_only() {
-        return this._favoritesOnly;
-    }
-
-    // eslint-disable-next-line camelcase
-    set favorites_only(favsOnly) {
-        if (this._favoritesOnly === favsOnly)
-            return;
-
-        this._favoritesOnly = favsOnly;
-        this.notify('favorites-only');
-    }
-
     setFilter(filter) {
         if (!Utils.updateTerms(this._filterTerms, filter))
             return;
@@ -196,7 +183,7 @@ export const ConnectionsList = GObject.registerClass({
         let usedNetworks = accounts.filter(a => a.predefined).map(a => a.service);
 
         this._networksManager.networks.forEach(network => {
-            if (this._favoritesOnly &&
+            if (this.favoritesOnly &&
                 !this._networksManager.getNetworkIsFavorite(network.id))
                 return;
 
@@ -259,16 +246,18 @@ export const ConnectionsList = GObject.registerClass({
     }
 });
 
-export const ConnectionDetails = GObject.registerClass({
-    Template: 'resource:///org/gnome/Polari/ui/connection-details.ui',
-    InternalChildren: [
+export const ConnectionDetails = GObject.registerClass(
+class ConnectionDetails extends Gtk.Box {
+    static [Gtk.template] = 'resource:///org/gnome/Polari/ui/connection-details.ui';
+    static [Gtk.internalChildren] = [
         'nameEntry',
         'serverEntry',
         'nickEntry',
         'realnameEntry',
-        'sslCheckbox',
-    ],
-    Properties: {
+        'sslSwitch',
+    ];
+
+    static [GObject.properties] = {
         'can-confirm': GObject.ParamSpec.boolean(
             'can-confirm', 'can-confirm', 'can-confirm',
             GObject.ParamFlags.READABLE,
@@ -277,21 +266,22 @@ export const ConnectionDetails = GObject.registerClass({
             'has-service', 'has-service', 'has-service',
             GObject.ParamFlags.READABLE,
             false),
-    },
-    Signals: {
+    };
+
+    static [GObject.signals] = {
         'account-created': { param_types: [Tp.Account.$gtype] },
-    },
-}, class ConnectionDetails extends Gtk.Grid {
-    _init(params) {
-        this._networksManager = NetworksManager.getDefault();
+    };
+
+    _networksManager = NetworksManager.getDefault();
+    _account = null;
+
+    constructor(params) {
+        super(params);
+
         let id = this._networksManager.connect('changed', () => {
             this.notify('has-service');
         });
 
-        this._account = null;
-
-        super._init(params);
-
         this.connect('destroy', () => {
             this._networksManager.disconnect(id);
         });
@@ -304,7 +294,7 @@ export const ConnectionDetails = GObject.registerClass({
             this._onCanConfirmChanged.bind(this));
         this._realnameEntry.connect('changed',
             this._onCanConfirmChanged.bind(this));
-        this._sslCheckbox.connect('toggled',
+        this._sslSwitch.connect('notify::active',
             this._onCanConfirmChanged.bind(this));
 
         let realnameStore = new Gtk.ListStore();
@@ -349,7 +339,7 @@ export const ConnectionDetails = GObject.registerClass({
 
         if (this._realnameEntry.text)
             params.fullname = this._realnameEntry.text.trim();
-        if (this._sslCheckbox.active)
+        if (this._sslSwitch.active)
             params.use_ssl = true;
         if (port)
             params.port = port;
@@ -370,7 +360,7 @@ export const ConnectionDetails = GObject.registerClass({
         this._serverEntry.text = this._savedServer;
         this._nickEntry.text = this._savedNick;
         this._realnameEntry.text = this._savedRealname;
-        this._sslCheckbox.active = this._savedSSL;
+        this._sslSwitch.active = this._savedSSL;
 
         if (this._serverEntry.visible)
             this._serverEntry.grab_focus();
@@ -402,7 +392,7 @@ export const ConnectionDetails = GObject.registerClass({
         this._nickEntry.text = this._savedNick;
         this._realnameEntry.text = this._savedRealname;
         this._nameEntry.text = this._savedName;
-        this._sslCheckbox.active = this._savedSSL;
+        this._sslSwitch.active = this._savedSSL;
     }
 
     // eslint-disable-next-line camelcase
@@ -411,7 +401,7 @@ export const ConnectionDetails = GObject.registerClass({
                             this._serverEntry.text !== this._savedServer ||
                             this._nickEntry.text !== this._savedNick ||
                             this._realnameEntry.text !== this._savedRealname ||
-                            this._sslCheckbox.active !== this._savedSSL;
+                            this._sslSwitch.active !== this._savedSSL;
 
         return this._serverEntry.get_text_length() > 0 &&
                this._nickEntry.get_text_length() > 0 &&
@@ -500,17 +490,18 @@ export const ConnectionDetails = GObject.registerClass({
 });
 
 
-export const ConnectionProperties = GObject.registerClass({
-    Template: 'resource:///org/gnome/Polari/ui/connection-properties.ui',
-    InternalChildren: [
+export const ConnectionProperties = GObject.registerClass(
+class ConnectionProperties extends Gtk.Dialog {
+    static [Gtk.template] = 'resource:///org/gnome/Polari/ui/connection-properties.ui';
+    static [Gtk.internalChildren] = [
         'details',
         'errorBox',
         'errorLabel',
-    ],
-}, class ConnectionProperties extends Gtk.Dialog {
-    _init(account) {
+    ];
+
+    constructor(account) {
         /* Translators: %s is a connection name */
-        super._init({
+        super({
             title: vprintf(_('“%s” Properties'), account.display_name),
             use_header_bar: 1,
         });
