@@ -1,3 +1,4 @@
+import Adw from 'gi://Adw';
 import Gio from 'gi://Gio';
 import GLib from 'gi://GLib';
 import GObject from 'gi://GObject';
@@ -6,7 +7,6 @@ import Polari from 'gi://Polari';
 import Tp from 'gi://TelepathyGLib';
 
 import AccountsMonitor from './accountsMonitor.js';
-import * as AppNotifications from './appNotifications.js';
 import JoinDialog from './joinDialog.js';
 import RoomList_ from './roomList.js'; // used in template
 import RoomManager from './roomManager.js';
@@ -14,23 +14,21 @@ import RoomStack_ from './roomStack.js'; // used in template
 import * as UserList_ from './userList.js'; // used in template
 import * as Utils from './utils.js';
 
-export const FixedSizeFrame = GObject.registerClass({
-    Properties: {
+export const FixedSizeFrame = GObject.registerClass(
+class FixedSizeFrame extends Gtk.Widget {
+    static [GObject.properties] = {
         height: GObject.ParamSpec.int(
             'height', 'height', 'height',
-            GObject.ParamFlags.READWRITE,
+            GObject.ParamFlags.READWRITE | GObject.ParamFlags.CONSTRUCT,
             -1, GLib.MAXINT32, -1),
         width: GObject.ParamSpec.int(
             'width', 'width', 'width',
-            GObject.ParamFlags.READWRITE,
+            GObject.ParamFlags.READWRITE | GObject.ParamFlags.CONSTRUCT,
             -1, GLib.MAXINT32, -1),
-    },
-}, class FixedSizeFrame extends Gtk.Widget {
-    _init(params) {
-        this._height = -1;
-        this._width = -1;
+    };
 
-        super._init({
+    constructor(params) {
+        super({
             ...params,
             layout_manager: new Gtk.BinLayout(),
         });
@@ -77,34 +75,22 @@ export const FixedSizeFrame = GObject.registerClass({
     }
 });
 
-export const HeaderBarButtonLayout = GObject.registerClass(
-class ButtonBinLayout extends Gtk.BinLayout {
-    vfunc_measure(widget, orientation, forSize) {
-        const [min, nat] = super.vfunc_measure(widget, orientation, forSize);
-        if (orientation === Gtk.Orientation.VERTICAL)
-            return [min, nat, -1, -1];
-
-        let [, height] = widget.measure(Gtk.Orientation.VERTICAL, -1);
-        const padding = widget.get_style_context().get_padding();
-        height -= padding.left + padding.right;
-        return [min, Math.max(nat, height), -1, -1];
-    }
-});
-
-export default GObject.registerClass({
-    Template: 'resource:///org/gnome/Polari/ui/main-window.ui',
-    InternalChildren: [
-        'titlebarRight',
-        'titlebarLeft',
+export default GObject.registerClass(
+class MainWindow extends Adw.ApplicationWindow {
+    static [Gtk.template] = 'resource:///org/gnome/Polari/ui/main-window.ui';
+    static [Gtk.internalChildren] = [
+        'backButton',
         'joinButton',
+        'mainLeaflet',
         'showUserListButton',
         'userListPopover',
         'roomListRevealer',
         'offlineInfoBar',
         'overlay',
         'roomStack',
-    ],
-    Properties: {
+    ];
+
+    static [GObject.properties] = {
         subtitle: GObject.ParamSpec.string(
             'subtitle', 'subtitle', 'subtitle',
             GObject.ParamFlags.READABLE,
@@ -121,40 +107,31 @@ export default GObject.registerClass({
             'view-height', 'view-height', 'view-height',
             GObject.ParamFlags.READABLE,
             0, GLib.MAXUINT32, 0),
-    },
-    Signals: {
+    };
+
+    static [GObject.signals] = {
         'active-room-state-changed': {},
-    },
-}, class MainWindow extends Gtk.ApplicationWindow {
-    _init(params) {
-        this._subtitle = '';
+    };
+
+    _lastActiveRoom = null;
+
+    _settings = new Gio.Settings({ schema_id: 'org.gnome.Polari' });
+
+    _currentSize = [-1, -1];
+    _isMaximized = false;
+    _isFullscreen = false;
+
+    _displayNameChangedId = 0;
+    _topicChangedId = 0;
+    _membersChangedId = 0;
+    _channelChangedId = 0;
+
+    constructor(params) {
         params.show_menubar = false;
-
-        this._room = null;
-        this._lastActiveRoom = null;
-
-        this._displayNameChangedId = 0;
-        this._topicChangedId = 0;
-        this._membersChangedId = 0;
-        this._channelChangedId = 0;
-
-        super._init(params);
+        super(params);
 
         this._userListPopover.set_parent(this._showUserListButton);
 
-        this._settings = new Gio.Settings({ schema_id: 'org.gnome.Polari' });
-        this._gtkSettings = Gtk.Settings.get_default();
-
-        this._currentSize = [-1, -1];
-        this._isMaximized = false;
-        this._isFullscreen = false;
-
-        this._notificationQueue = new AppNotifications.NotificationQueue();
-        this._commandOutputQueue = new AppNotifications.CommandOutputQueue();
-
-        this._overlay.add_overlay(this._notificationQueue);
-        this._overlay.add_overlay(this._commandOutputQueue);
-
         const app = this.application;
         if (app.isTestInstance)
             this.add_css_class('test-instance');
@@ -163,16 +140,10 @@ export default GObject.registerClass({
 
         this._roomStack.connect('notify::view-height',
             () => this.notify('view-height'));
-
-        // command output notifications should not pop up over
-        // the input area, but appear to emerge from it, so
-        // set up an appropriate margin
-        this._roomStack.bind_property('entry-area-height',
-            this._commandOutputQueue, 'margin-bottom',
-            GObject.BindingFlags.SYNC_CREATE);
-
-        // Make sure user-list button is at least as wide as icon buttons
-        this._showUserListButton.layout_manager = new HeaderBarButtonLayout();
+        this._roomStack.connect('notify::visible-child',
+            () => this._mainLeaflet.navigate(Adw.NavigationDirection.FORWARD));
+        this._backButton.connect('clicked',
+            () => this._mainLeaflet.navigate(Adw.NavigationDirection.BACKWARD));
 
         this._accountsMonitor = AccountsMonitor.getDefault();
         this._accountsChangedId = this._accountsMonitor.connect(
@@ -205,10 +176,6 @@ export default GObject.registerClass({
                 this._userListAction.change_state(GLib.Variant.new('b', false));
         });
 
-        this._gtkSettings.connect('notify::gtk-decoration-layout',
-            this._updateDecorations.bind(this));
-        this._updateDecorations();
-
         this.connect('notify::maximized',
             () => (this._isMaximized = this.maximized));
         this.connect('notify::fullscreened',
@@ -231,12 +198,12 @@ export default GObject.registerClass({
     }
 
     get subtitle() {
-        return this._subtitle;
+        return this._subtitle ?? '';
     }
 
     // eslint-disable-next-line camelcase
     get subtitle_visible() {
-        return this._subtitle.length > 0;
+        return this.subtitle.length > 0;
     }
 
     // eslint-disable-next-line camelcase
@@ -245,17 +212,10 @@ export default GObject.registerClass({
     }
 
     /**
-     * @param {AppNotification} n - a notification
+     * @param {Adw.Toast} toast - a toast (cheers!)
      */
-    queueNotification(n) {
-        this._notificationQueue.addNotification(n);
-    }
-
-    /**
-     * @param {AppNotification} n - a notification
-     */
-    queueCommandOutput(n) {
-        this._commandOutputQueue.addNotification(n);
+    addToast(toast) {
+        this._overlay.add_toast(toast);
     }
 
     _onAccountsReachableChanged() {
@@ -301,22 +261,6 @@ export default GObject.registerClass({
         return layoutStr.split(',').filter(s => s !== 'menu').join(',');
     }
 
-    _updateDecorations() {
-        let layoutLeft = null;
-        let layoutRight = null;
-
-        let layout = this._gtkSettings.gtk_decoration_layout;
-        if (layout) {
-            let [buttonsLeft, buttonsRight] = layout.split(':');
-
-            layoutLeft = `${this._filterFallbackAppMenu(buttonsLeft)}:`;
-            layoutRight = `:${this._filterFallbackAppMenu(buttonsRight)}`;
-        }
-
-        this._titlebarLeft.set_decoration_layout(layoutLeft);
-        this._titlebarRight.set_decoration_layout(layoutRight);
-    }
-
     // eslint-disable-next-line camelcase
     get active_room() {
         return this._room;
@@ -410,7 +354,7 @@ export default GObject.registerClass({
             '%d users', numMembers), numMembers);
         this._showUserListButton.update_property(
             [Gtk.AccessibleProperty.LABEL], [accessibleName]);
-        this._showUserListButton.label = `${numMembers}`;
+        this._showUserListButton.child.label = `${numMembers}`;
     }
 
     _updateTitlebar() {
